==> singularity-container_3.0.3+ds.orig.tar.gz: singularity-container-3.0.3/CONTRIBUTORS.md <==
# Project Lead:

    - Gregory M. Kurtzer <g@sylabs.io>

# Maintainers:

    - Michael Bauer <m@sylabs.io>, <bauerm@umich.edu>
    - Yannick Cote <y@sylabs.io>, <yhcote@gmail.com>
    - Dave Godlove <d@sylabs.io>, <davidgodlove@gmail.com>

# Contributors:

    - Adam Hughes <adam@sylabs.io>, <stickmanica@gmail.com>
    - Afif Elghraoui <afif.elghraoui@nih.gov>
    - Amanda Duffy <aduffy@lenovo.com>
    - Ángel Bejarano <abejarano@ontropos.com>
    - Bernard Li <bernardli@lbl.gov>
    - Brian Bockelman <bbockelm@cse.unl.edu>
    - Carl Madison <carl@sylabs.io>
    - Cedric Clerget <cedric@sylabs.io>, <cedric.clerget@univ-fcomte.fr>
    - Chris Hollowell <hollowec@bnl.gov>
    - Christian Neyers <foss@neyers.org>
    - Daniele Tamino <daniele.tamino@gmail.com>
    - Dave Dykstra <dwd@fnal.gov>
    - Dave Godlove <d@sylabs.io>, <davidgodlove@gmail.com>
    - Dave Love <d.love@liverpool.ac.uk>
    - David Trudgian <david.trudgian@utsouthwestern.edu>
    - Diana Langenbach <dcl@dcl.sh>
    - Divya Cote <divya.cote@gmail.com>
    - Eduardo Arango <eduardo@sylabs.io>, <arangogutierrez@gmail.com>
    - Felix Abecassis <fabecassis@nvidia.com>
    - George Hartzell <hartzell@alerce.com>
    - Gert Hulselmans <gert.hulselmans@kuleuven.vib.be>
    - Hakon Enger <hakonenger@github.com>
    - Hugo Meiland <hugo.meiland@microsoft.com>
    - Ian Kaneshiro <ian@sylabs.io>, <iankane@umich.edu>
    - Jacob Chappell <chappellind@gmail.com>, <jacob.chappell@uky.edu>
    - Jarrod Johnson <jjohnson2@lenovo.com>
    - Jason Stover <jms@sylabs.io>, <jason.stover@gmail.com>
    - Jeff Kriske <jekriske@gmail.com>
    - Josef Hrabal <josef.hrabal@vsb.cz>
    - Justin Riley <justin_riley@harvard.edu>
    - Krishna Muriki <kmuriki@lbl.gov>
    - Kundan Kumar <iamkundankumar28@gmail.com>
    - Maciej Sieczka <msieczka@sieczka.org>
    - Mark Egan-Fuller <markeganfuller@googlemail.com>
    - Matt Wiens <mwiens91@gmail.com>
    - Michael Bauer <m@sylabs.io>, <bauerm@umich.edu>
    - Michael Herzberg <michael@mherzberg.de>
    - Nathan Lin <nathan.lin@yale.edu>
    - Oleksandr Moskalenko <om@rc.ufl.edu>
    - Oliver Freyermuth <freyermuth@physik.uni-bonn.de>
    - Olivier Sallou <olivier.sallou@irisa.fr>
    - Peter Steinbach <steinbach@scionics.de>
    - Petr Votava <votava.petr@gene.com>
    - Rafal Gumienny <rafal.gumienny@gmail.com>
    - Ralph Castain <rhc@open-mpi.org>
    - Rémy Dernat <remy.dernat@umontpellier.fr>
    - Richard Neuboeck <hawk@tbi.univie.ac.at>
    - Tarcisio Fedrizzi <tarcisio.fedrizzi@gmail.com>
    - Thomas Hamel <hmlth@t-hamel.fr>
    - Vanessa Sochat <vsochat@stanford.edu>
    - Westley Kurtzer <westley@sylabs.io>
    - Yannick Cote <y@sylabs.io>, <yhcote@gmail.com>
    - Yaroslav Halchenko <debian@onerussian.com>

==> singularity-container_3.1.1+ds.orig.tar.gz: singularity-container-3.1.1/CONTRIBUTORS.md <==
# Project Lead:

    - Gregory M. Kurtzer <g@sylabs.io>

# Maintainers:

    - Michael Bauer <m@sylabs.io>, <bauerm@umich.edu>
    - Yannick Cote <y@sylabs.io>, <yhcote@gmail.com>
    - Dave Godlove <d@sylabs.io>, <davidgodlove@gmail.com>

# Contributors:

    - Adam Hughes <adam@sylabs.io>, <stickmanica@gmail.com>
    - Afif Elghraoui <afif.elghraoui@nih.gov>
    - Amanda Duffy <aduffy@lenovo.com>
    - Ángel Bejarano <abejarano@ontropos.com>
    - Bernard Li <bernardli@lbl.gov>
    - Brian Bockelman <bbockelm@cse.unl.edu>
    - Carl Madison <carl@sylabs.io>
    - Cedric Clerget <cedric@sylabs.io>, <cedric.clerget@univ-fcomte.fr>
    - Chris Hollowell <hollowec@bnl.gov>
    - Christian Neyers <foss@neyers.org>
    - Daniele Tamino <daniele.tamino@gmail.com>
    - Dave Dykstra <dwd@fnal.gov>
    - Dave Godlove <d@sylabs.io>, <davidgodlove@gmail.com>
    - Dave Love <d.love@liverpool.ac.uk>
    - David Trudgian <david.trudgian@utsouthwestern.edu>
    - Diana Langenbach <dcl@dcl.sh>
    - Divya Cote <divya.cote@gmail.com>
    - Eduardo Arango <eduardo@sylabs.io>, <arangogutierrez@gmail.com>
    - Felix Abecassis <fabecassis@nvidia.com>
    - Geoffroy Vallee <geoffroy@sylabs.io>, <geoffroy.vallee@gmail.com>
    - George Hartzell <hartzell@alerce.com>
    - Gert Hulselmans <gert.hulselmans@kuleuven.vib.be>
    - Hakon Enger <hakonenger@github.com>
    - Hugo Meiland <hugo.meiland@microsoft.com>
    - Ian Kaneshiro <ian@sylabs.io>, <iankane@umich.edu>
    - Jacob Chappell <chappellind@gmail.com>, <jacob.chappell@uky.edu>
    - Jarrod Johnson <jjohnson2@lenovo.com>
    - Jason Stover <jms@sylabs.io>, <jason.stover@gmail.com>
    - Jeff Kriske <jekriske@gmail.com>
    - Joana Chavez <joana@sylabs.io>, <j.chavezlavalle@gmail.com>
    - Josef Hrabal <josef.hrabal@vsb.cz>
    - Justin Riley <justin_riley@harvard.edu>
    - Krishna Muriki <kmuriki@lbl.gov>
    - Kumar Sukhani <kumarsukhani@gmail.com>
    - Kundan Kumar <iamkundankumar28@gmail.com>
    - Maciej Sieczka <msieczka@sieczka.org>
    - Mark Egan-Fuller <markeganfuller@googlemail.com>
    - Matt Wiens <mwiens91@gmail.com>
    - Michael Bauer <m@sylabs.io>, <bauerm@umich.edu>
    - Michael Herzberg <michael@mherzberg.de>
    - Michael Milton <ttmigueltt@gmail.com>
    - Nathan Lin <nathan.lin@yale.edu>
    - Oleksandr Moskalenko <om@rc.ufl.edu>
    - Oliver Freyermuth <freyermuth@physik.uni-bonn.de>
    - Olivier Sallou <olivier.sallou@irisa.fr>
    - Peter Steinbach <steinbach@scionics.de>
    - Petr Votava <votava.petr@gene.com>
    - Rafal Gumienny <rafal.gumienny@gmail.com>
    - Ralph Castain <rhc@open-mpi.org>
    - Rémy Dernat <remy.dernat@umontpellier.fr>
    - Richard Neuboeck <hawk@tbi.univie.ac.at>
    - Sasha Yakovtseva <sasha@sylabs.io>, <sashayakovtseva@gmail.com>
    - Tarcisio Fedrizzi <tarcisio.fedrizzi@gmail.com>
    - Thomas Hamel <hmlth@t-hamel.fr>
    - Vanessa Sochat <vsochat@stanford.edu>
    - Westley Kurtzer <westley@sylabs.io>
    - Yannick Cote <y@sylabs.io>, <yhcote@gmail.com>
    - Yaroslav Halchenko <debian@onerussian.com>
